SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

CREATE SCHEMA IF NOT EXISTS `Werbung` DEFAULT CHARACTER SET latin1 COLLATE latin1_swedish_ci ;
USE `Werbung` ;

-- -----------------------------------------------------
-- Table `Werbung`.`Werbeflaechen`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Werbung`.`Werbeflaechen` ;

CREATE  TABLE IF NOT EXISTS `Werbung`.`Werbeflaechen` (
  `werbeflaechennr` INT NOT NULL ,
  `bezeichnung` VARCHAR(45) NULL ,
  `groesseInQuadratmeter` DOUBLE NULL ,
  PRIMARY KEY (`werbeflaechennr`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Werbung`.`Rennveranstaltungen`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Werbung`.`Rennveranstaltungen` ;

CREATE  TABLE IF NOT EXISTS `Werbung`.`Rennveranstaltungen` (
  `rennveranstaltungsnr` INT NOT NULL ,
  `name` VARCHAR(45) NULL ,
  `datum` DATE NULL ,
  PRIMARY KEY (`rennveranstaltungsnr`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Werbung`.`Sponsoren`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Werbung`.`Sponsoren` ;

CREATE  TABLE IF NOT EXISTS `Werbung`.`Sponsoren` (
  `sponsorennr` INT NOT NULL ,
  `name` VARCHAR(45) NULL ,
  PRIMARY KEY (`sponsorennr`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Werbung`.`Vermietungen`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `Werbung`.`Vermietungen` ;

CREATE  TABLE IF NOT EXISTS `Werbung`.`Vermietungen` (
  `vermietungsnr` INT NOT NULL ,
  `mietpreis` DOUBLE NULL ,
  `werbeflaechennr` INT NOT NULL ,
  `sponsorennr` INT NOT NULL ,
  `rennveranstaltungsnr` INT NOT NULL ,
  PRIMARY KEY (`vermietungsnr`) ,
  INDEX `fk_Vermietungen_Werbeflaechen` (`werbeflaechennr` ASC) ,
  INDEX `fk_Vermietungen_Sponsoren1` (`sponsorennr` ASC) ,
  INDEX `fk_Vermietungen_Rennveranstaltungen1` (`rennveranstaltungsnr` ASC) ,
  CONSTRAINT `fk_Vermietungen_Werbeflaechen`
    FOREIGN KEY (`werbeflaechennr` )
    REFERENCES `Werbung`.`Werbeflaechen` (`werbeflaechennr` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Vermietungen_Sponsoren1`
    FOREIGN KEY (`sponsorennr` )
    REFERENCES `Werbung`.`Sponsoren` (`sponsorennr` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Vermietungen_Rennveranstaltungen1`
    FOREIGN KEY (`rennveranstaltungsnr` )
    REFERENCES `Werbung`.`Rennveranstaltungen` (`rennveranstaltungsnr` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;



SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;

INSERT INTO `werbung`.`werbeflaechen` (`werbeflaechennr`, `bezeichnung`, `groesseInQuadratmeter`) VALUES ('1', 'Start/Ziel', '45'); 
INSERT INTO `werbung`.`werbeflaechen` (`werbeflaechennr`, `bezeichnung`, `groesseInQuadratmeter`) VALUES ('2', 'Steilkurve', '38'); 
INSERT INTO `werbung`.`werbeflaechen` (`werbeflaechennr`, `bezeichnung`, `groesseInQuadratmeter`) VALUES ('3', 'Nordschleife', '20'); 
INSERT INTO `werbung`.`werbeflaechen` (`werbeflaechennr`, `bezeichnung`, `groesseInQuadratmeter`) VALUES ('4', 'Alphatribüne', '30'); 
INSERT INTO `werbung`.`werbeflaechen` (`werbeflaechennr`, `bezeichnung`, `groesseInQuadratmeter`) VALUES ('5', 'Südkurve', '36'); 
INSERT INTO `werbung`.`werbeflaechen` (`werbeflaechennr`, `bezeichnung`, `groesseInQuadratmeter`) VALUES ('6', 'Schikane', '18'); 
INSERT INTO `werbung`.`werbeflaechen` (`werbeflaechennr`, `bezeichnung`, `groesseInQuadratmeter`) VALUES ('7', 'Haupttribüne', '59');

INSERT INTO `werbung`.`sponsoren` (`sponsorennr`, `name`) VALUES ('10', 'Tiefenstill Mineralwasser'); 
INSERT INTO `werbung`.`sponsoren` (`sponsorennr`, `name`) VALUES ('11', 'Autohaus Maier'); 
INSERT INTO `werbung`.`sponsoren` (`sponsorennr`, `name`) VALUES ('12', 'Grupp Design'); 
INSERT INTO `werbung`.`sponsoren` (`sponsorennr`, `name`) VALUES ('13', 'Bilch Gartenmöbel'); 
INSERT INTO `werbung`.`sponsoren` (`sponsorennr`, `name`) VALUES ('14', 'Assauer Motor-Pimp'); 
INSERT INTO `werbung`.`sponsoren` (`sponsorennr`, `name`) VALUES ('15', 'Ebike Seetler'); 
INSERT INTO `werbung`.`sponsoren` (`sponsorennr`, `name`) VALUES ('16', 'Motorcycles Gschwender');


INSERT INTO `werbung`.`rennveranstaltungen` (`rennveranstaltungsnr`, `name`, `datum`) VALUES ('100', 'Sachsenspeed', '2014-07-23'); 
INSERT INTO `werbung`.`rennveranstaltungen` (`rennveranstaltungsnr`, `name`, `datum`) VALUES ('101', 'Nürburgrace', '2014-08-15'); 
INSERT INTO `werbung`.`rennveranstaltungen` (`rennveranstaltungsnr`, `name`, `datum`) VALUES ('102', 'Freiburg Challenge', '2014-05-30'); 
INSERT INTO `werbung`.`rennveranstaltungen` (`rennveranstaltungsnr`, `name`, `datum`) VALUES ('103', 'Großer Preis von Württemberg', '2014-07-24'); 
INSERT INTO `werbung`.`rennveranstaltungen` (`rennveranstaltungsnr`, `name`, `datum`) VALUES ('104', 'Hamburg Open Speedrace', '2014-09-13'); 
INSERT INTO `werbung`.`rennveranstaltungen` (`rennveranstaltungsnr`, `name`, `datum`) VALUES ('105', 'Stuttgart Cup', '2014-07-28'); 
INSERT INTO `werbung`.`rennveranstaltungen` (`rennveranstaltungsnr`, `name`, `datum`) VALUES ('106', 'Stuttgart Hall of Fame 2014', '2014-05-18'); 
INSERT INTO `werbung`.`rennveranstaltungen` (`rennveranstaltungsnr`, `name`, `datum`) VALUES ('107', 'Bayern High Pull', '2014-08-22'); 

INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('201', '1700', '1', '14', '100'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('202', '20400', '1', '13', '103'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('203', '13750', '2', '15', '100'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('204', '8650', '2', '10', '101'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('205', '4000', '2', '11', '106'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('206', '3300', '3', '12', '105'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('207', '13500', '3', '16', '106'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('208', '28000', '3', '15', '107'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('209', '17400', '4', '14', '100'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('210', '2900', '4', '13', '104'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('211', '9800', '4', '10', '107'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('212', '3540', '6', '12', '102'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('213', '3000', '6', '11', '103'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('214', '5400', '6', '16', '105'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('215', '9900', '6', '16', '107'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('216', '18900', '7', '14', '100'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('217', '12500', '7', '15', '101'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('218', '7800', '7', '12', '102'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('219', '12000', '7', '13', '104'); 
INSERT INTO `werbung`.`vermietungen` (`vermietungsnr`, `mietpreis`, `werbeflaechennr`, `sponsorennr`, `rennveranstaltungsnr`) VALUES ('220', '17000', '7', '14', '107'); 
