-- ----------------------------------------------------------------------
-- MySQL Migration Toolkit
-- SQL Create Script
-- ----------------------------------------------------------------------

SET FOREIGN_KEY_CHECKS = 0;

DROP DATABASE IF EXISTS zirkus;
CREATE DATABASE IF NOT EXISTS zirkus
  CHARACTER SET utf8 COLLATE utf8_general_ci;
USE zirkus;
-- -------------------------------------
-- Tables

CREATE TABLE zirkus.bestellpositionen (
  Bestellpositionsnummer INT(10) NOT NULL,
  Bestellnummer INT(10) NULL,
  Menge DOUBLE(15,5) NULL,
  Futtermittelnummer INT(10) NULL,
  PRIMARY KEY (Bestellpositionsnummer),
  INDEX Bestellnummer (Bestellnummer),
  INDEX Bestellpositionsnummer (Bestellpositionsnummer),
  INDEX BestellungenBestellpositionen (Bestellnummer),
  INDEX FuttermittelBestellpositionen (Futtermittelnummer),
  INDEX Futtermittelnummer (Futtermittelnummer)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE zirkus.bestellungen (
  Bestellnummer INT(10) NOT NULL,
  Bestelldatum DATETIME NULL,
  LNummer INT(10) NOT NULL,
  PRIMARY KEY (Bestellnummer),
  INDEX Bestellnummer (Bestellnummer),
  INDEX LieferantenBestellungen (LNummer),
  INDEX LNummer (LNummer)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE zirkus.futtermittel (
  Futtermittelnummer INT(10) NOT NULL,
  Hoechstbestand DOUBLE(15,5) NULL,
  Futtermittelpreis DOUBLE(15,5) NULL,
  Meldebestand DOUBLE(15,5) NULL,
  Lagerbestand DOUBLE(15,5) NULL,
  Futtermittelname VARCHAR(255) NULL,
  Futtermitteleinheit VARCHAR(255) NULL,
  PRIMARY KEY (Futtermittelnummer)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE zirkus.futtermittelzuweisungen (
  Futtermittelzuweisungsnummer INT(10) NOT NULL,
  Menge DOUBLE(15,5) NULL,
  Tiernummer INT(10) NOT NULL,
  Futtermittelnummer INT(10) NULL,
  PRIMARY KEY (Futtermittelzuweisungsnummer),
  UNIQUE INDEX Index_6F4237F6_1DA3_44AE (Futtermittelzuweisungsnummer),
  INDEX REF7 (Tiernummer),
  INDEX REF8 (Futtermittelnummer)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE zirkus.lieferanten (
  Lnummer INT(10) NOT NULL,
  Lieferantenname1 VARCHAR(50) NULL,
  Lieferantenname2 VARCHAR(50) NULL,
  Telefon VARCHAR(15) NULL,
  Telefax VARCHAR(15) NULL,
  Ansprechpartner VARCHAR(20) NULL,
  PRIMARY KEY (Lnummer),
  INDEX Lieferantennummer (Lnummer)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE zirkus.tierarten (
  Tierartnummer INT(10) NOT NULL,
  Tierartbezeichnung VARCHAR(30) NULL,
  PRIMARY KEY (Tierartnummer),
  UNIQUE INDEX Index_41E122E5_2051_4F19 (Tierartnummer)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;

CREATE TABLE zirkus.tiere (
  Tiernummer INT(10) NOT NULL,
  Tiername VARCHAR(30) NULL,
  GebDat DATETIME NULL,
  Sex VARCHAR(30) NULL,
  Geburtsland VARCHAR(30) NULL,
  Tierartnummer INT(10) NOT NULL,
  PRIMARY KEY (Tiernummer),
  UNIQUE INDEX Index_3F038F45_CB66_463A (Tiernummer),
  INDEX REF0 (Tierartnummer)
)
ENGINE = INNODB
CHARACTER SET utf8 COLLATE utf8_general_ci;



SET FOREIGN_KEY_CHECKS = 1;

-- ----------------------------------------------------------------------
-- SQL data bulk transfer script generated by the MySQL Migration Toolkit
-- ----------------------------------------------------------------------

-- Disable foreign key checks
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;

INSERT INTO `zirkus`.`bestellpositionen`(`Bestellpositionsnummer`, `Bestellnummer`, `Menge`, `Futtermittelnummer`)
VALUES (1, 1, 200.00000, 1),
  (2, 9, 400.00000, 1),
  (3, 8, 200.00000, 1),
  (4, 6, 500.00000, 1),
  (5, 8, 10.00000, 10),
  (6, 8, 15.00000, 17),
  (7, 2, 17.00000, 18),
  (8, 3, 20.00000, 17),
  (9, 4, 20.00000, 7),
  (10, 1, 10.00000, 2),
  (11, 5, 5.00000, 11),
  (12, 9, 10.00000, 15),
  (13, 1, 7.00000, 12),
  (14, 2, 1.00000, 3);

INSERT INTO `zirkus`.`bestellungen`(`Bestellnummer`, `Bestelldatum`, `LNummer`)
VALUES (1, '2010-10-12 00:00:00', 1),
  (2, '2010-10-12 00:00:00', 2),
  (3, '2010-10-12 00:00:00', 3),
  (4, '2010-10-20 00:00:00', 1),
  (5, '2010-10-21 00:00:00', 2),
  (6, '2010-10-22 00:00:00', 1),
  (8, '2010-10-25 00:00:00', 3),
  (9, '2010-10-26 00:00:00', 1);

INSERT INTO `zirkus`.`futtermittel`(`Futtermittelnummer`, `Hoechstbestand`, `Futtermittelpreis`, `Meldebestand`, `Lagerbestand`, `Futtermittelname`, `Futtermitteleinheit`)
VALUES (1, 7000.00000, 0.50000, 500.00000, 5000.00000, 'Hafer                                                                                                                                                                                                                                                          ', 'kg                                                                                                                                                                                                                                                             '),
  (2, 100.00000, 5.00000, 10.00000, 5.00000, 'Heu                                                                                                                                                                                                                                                            ', 'Zentner                                                                                                                                                                                                                                                        '),
  (3, 10.00000, 6.00000, 0.00000, 5.00000, 'Klee                                                                                                                                                                                                                                                           ', 'Zentner                                                                                                                                                                                                                                                        '),
  (4, 7000.00000, 39.00000, 500.00000, 1500.00000, 'Gerste_Weizen                                                                                                                                                                                                                                                  ', 'kg                                                                                                                                                                                                                                                             '),
  (5, 1000.00000, 3.50000, 200.00000, 150.00000, 'Rohfleisch                                                                                                                                                                                                                                                     ', 'Kg                                                                                                                                                                                                                                                             '),
  (6, 200.00000, 2.50000, 50.00000, 70.00000, 'Freibankfleisch                                                                                                                                                                                                                                                ', 'kg                                                                                                                                                                                                                                                             '),
  (7, 100.00000, 4.50000, 50.00000, 32.00000, 'Rohfisch                                                                                                                                                                                                                                                       ', 'kg                                                                                                                                                                                                                                                             '),
  (8, 200.00000, 0.80000, 10.00000, 106.00000, 'Mäuse                                                                                                                                                                                                                                                          ', 'Stück                                                                                                                                                                                                                                                          '),
  (9, 300.00000, 4.00000, 50.00000, 80.00000, 'Körnermischung                                                                                                                                                                                                                                                 ', 'kg                                                                                                                                                                                                                                                             '),
  (10, 30.00000, 7.50000, 10.00000, 15.00000, 'Nussmischung                                                                                                                                                                                                                                                   ', 'kg                                                                                                                                                                                                                                                             '),
  (11, 20.00000, 9.80000, 7.00000, 13.00000, 'Vitaminzusatz                                                                                                                                                                                                                                                  ', 'kg                                                                                                                                                                                                                                                             '),
  (12, 50.00000, 8.80000, 10.00000, 23.00000, 'Mineralienmischung                                                                                                                                                                                                                                             ', 'kg                                                                                                                                                                                                                                                             '),
  (13, 150.00000, 0.23000, 20.00000, 60.00000, 'Hühnereier                                                                                                                                                                                                                                                     ', 'Stück                                                                                                                                                                                                                                                          '),
  (14, 80.00000, 0.80000, 20.00000, 40.00000, 'Gemüse _Salat                                                                                                                                                                                                                                                  ', 'kg                                                                                                                                                                                                                                                             '),
  (15, 45.00000, 0.70000, 15.00000, 30.00000, 'Obst                                                                                                                                                                                                                                                           ', 'kg                                                                                                                                                                                                                                                             '),
  (16, 35.00000, 53.00000, 5.00000, 10.00000, 'Mais                                                                                                                                                                                                                                                           ', 'Zentner                                                                                                                                                                                                                                                        '),
  (17, 30.00000, 8.00000, 5.00000, 20.00000, 'Rüben                                                                                                                                                                                                                                                          ', 'Zentner                                                                                                                                                                                                                                                        '),
  (18, 20.00000, 0.30000, 5.00000, 6.00000, 'Katzenfutter                                                                                                                                                                                                                                                   ', 'Dose                                                                                                                                                                                                                                                           ');

INSERT INTO `zirkus`.`futtermittelzuweisungen`(`Futtermittelzuweisungsnummer`, `Menge`, `Tiernummer`, `Futtermittelnummer`)
VALUES (1, 0.02857, 10, 2),
  (2, 0.00143, 10, 3),
  (3, 0.00143, 10, 17),
  (4, 0.01429, 11, 2),
  (5, 0.00143, 11, 3),
  (6, 0.00143, 11, 17),
  (7, 4.00000, 5, 6),
  (8, 4.00000, 6, 6),
  (9, 4.00000, 7, 6),
  (10, 1.00000, 9, 18),
  (11, 3.00000, 13, 1),
  (12, 1.00000, 13, 2),
  (13, 0.10000, 13, 11),
  (14, 3.00000, 14, 1),
  (15, 1.00000, 14, 2),
  (16, 0.10000, 14, 11),
  (17, 3.00000, 15, 1),
  (18, 1.00000, 15, 2),
  (19, 0.10000, 15, 11),
  (20, 3.00000, 16, 1),
  (21, 1.00000, 16, 2),
  (22, 0.10000, 16, 11),
  (23, 3.00000, 17, 1),
  (24, 1.00000, 17, 2),
  (25, 0.10000, 17, 11),
  (26, 3.00000, 18, 1),
  (27, 1.00000, 18, 2),
  (28, 0.10000, 18, 11),
  (29, 3.00000, 19, 1),
  (30, 1.00000, 19, 2),
  (31, 0.10000, 19, 11),
  (32, 3.00000, 20, 1),
  (33, 1.00000, 20, 2),
  (34, 0.10000, 20, 11),
  (35, 3.00000, 21, 1),
  (36, 1.00000, 21, 2),
  (37, 0.10000, 21, 11),
  (38, 3.00000, 22, 1),
  (39, 1.00000, 22, 2),
  (40, 0.10000, 22, 11),
  (41, 3.00000, 23, 1),
  (42, 1.00000, 23, 2),
  (43, 0.10000, 23, 11),
  (44, 3.00000, 24, 1),
  (45, 1.00000, 24, 2),
  (46, 0.10000, 24, 11),
  (47, 3.00000, 25, 1),
  (48, 1.00000, 25, 2),
  (49, 0.10000, 25, 11),
  (50, 3.00000, 26, 1),
  (51, 1.00000, 26, 2),
  (52, 0.10000, 26, 11),
  (53, 3.00000, 27, 1),
  (54, 1.00000, 27, 2),
  (55, 0.10000, 27, 11),
  (56, 0.28571, 28, 14),
  (57, 0.28571, 29, 14),
  (58, 0.14286, 28, 4),
  (59, 0.14286, 29, 4),
  (60, 0.03571, 28, 12),
  (61, 0.03571, 29, 12),
  (62, 0.01429, 3, 10),
  (63, 0.01429, 4, 10),
  (64, 0.00143, 3, 11),
  (65, 0.00143, 4, 11),
  (66, 0.01429, 3, 15),
  (67, 0.01429, 4, 15),
  (68, 0.01429, 3, 9),
  (69, 0.01429, 4, 9),
  (70, 0.03571, 1, 2),
  (71, 0.03571, 2, 2),
  (72, 0.01429, 1, 3),
  (73, 0.01429, 2, 3),
  (74, 0.57143, 1, 14),
  (75, 0.57143, 2, 14),
  (76, 0.42857, 1, 15),
  (77, 0.42857, 2, 15),
  (78, 0.03571, 1, 4),
  (79, 0.50000, 8, 5),
  (80, 0.14286, 8, 12),
  (82, 2.00000, 12, 7),
  (83, 0.10000, 12, 12),
  (84, 0.10000, 12, 11),
  (85, 1.00000, 12, 15),
  (86, 1.00000, 30, 14),
  (88, 0.50000, 30, 17),
  (89, 0.50000, 30, 15),
  (90, 0.57143, 31, 8),
  (91, 1.00000, 31, 18),
  (92, 1.00000, 31, 13),
  (93, 0.10000, 31, 7),
  (94, 2.00000, 32, 8),
  (95, 1.00000, 32, 6),
  (96, 0.03571, 33, 4),
  (97, 0.42857, 33, 15),
  (98, 0.57143, 33, 14),
  (99, 0.03571, 33, 3),
  (100, 0.01429, 33, 2),
  (101, 0.14286, 34, 2),
  (102, 0.14286, 34, 3),
  (103, 0.07143, 34, 16),
  (104, 0.42857, 35, 8),
  (105, 1.00000, 35, 13),
  (106, 0.10000, 2, 1),
  (108, 0.42857, 6, 5);

INSERT INTO `zirkus`.`lieferanten`(`Lnummer`, `Lieferantenname1`, `Lieferantenname2`, `Telefon`, `Telefax`, `Ansprechpartner`)
VALUES (1, 'ZG NRW-West', 'Landw. Genossenschaft', '0241/454565', '0241/454501', 'Herr Kaiserdom'),
  (2, 'ZG Baden', 'Raiffeisengenossenschaft', '07531/61947', '07531/61945', 'Herr Schmalstieg'),
  (3, 'Landgut Freising', 'Genossenschaft', '08161/4321', '08361/4322', 'Frau Amberg'),
  (4, 'Holstein ZG', 'Raiffeisengenossenschaft', '0431/55564', '0431/55565', 'Frau Sprotte'),
  (5, 'LPG-Bedarf', 'Zentralgenossenschaft', '0341/2334', '0341/2335', 'Herr Allerlei');

INSERT INTO `zirkus`.`tierarten`(`Tierartnummer`, `Tierartbezeichnung`)
VALUES (1, 'Esel                          '),
  (2, 'Papagei                       '),
  (3, 'Löwe                          '),
  (4, 'Hund                          '),
  (5, 'Hauskatze                     '),
  (6, 'Kamel                         '),
  (7, 'Aligator                      '),
  (8, 'Fuchs                         '),
  (9, 'Wildschwein                   '),
  (10, 'Araber Pferd                  '),
  (11, 'Pferd Holsteiner              '),
  (12, 'Pferd  Trakoner               '),
  (13, 'Lama                          '),
  (14, 'Eisbär                        '),
  (15, 'Gans'),
  (16, 'Schimpanse'),
  (17, 'Boa'),
  (18, 'Rind');

INSERT INTO `zirkus`.`tiere`(`Tiernummer`, `Tiername`, `GebDat`, `Sex`, `Geburtsland`, `Tierartnummer`)
VALUES (1, 'Moses                         ', '1986-11-24 00:00:00', 'm                             ', 'Griechenland                  ', 1),
  (2, 'Rea                           ', '1995-07-14 00:00:00', 'w                             ', 'Italien                       ', 1),
  (3, 'Jako                          ', '2005-03-14 00:00:00', 'm                             ', 'Deutschland                   ', 2),
  (4, 'Rosi                          ', '2004-05-15 00:00:00', 'w                             ', 'Deutschland                   ', 2),
  (5, 'Cäsar                         ', '2000-07-26 00:00:00', 'm                             ', 'Sambia', 3),
  (6, 'Cleopatra                     ', '2002-05-01 00:00:00', 'w                             ', 'Rumänien                      ', 3),
  (7, 'Hatschepsut                   ', '2004-01-08 00:00:00', 'w                             ', 'Portugal                      ', 3),
  (8, 'Wanda                         ', '2002-03-30 00:00:00', 'w                             ', 'Deutschland                   ', 4),
  (9, 'Mom                           ', '2000-01-01 00:00:00', 'w                             ', 'Deutschland                   ', 5),
  (10, 'Ali                           ', '1994-07-04 00:00:00', 'm                             ', 'Ägypten                       ', 6),
  (11, 'Ben                           ', '1998-10-09 00:00:00', 'm                             ', 'Tunesien                      ', 6),
  (12, 'Molly                         ', '1996-10-25 00:00:00', 'w                             ', 'Deutschland                   ', 14),
  (13, 'Fanny', '1994-11-29 00:00:00', 'w', 'Frankreich', 10),
  (14, 'Melly', '1991-10-25 00:00:00', 'w', 'Frankreich', 10),
  (15, 'Kaschin', '1996-03-02 00:00:00', 'w', 'Holland', 10),
  (16, 'Sarina', '1997-04-16 00:00:00', 'w', 'Dänemark', 10),
  (17, 'Gangina', '1997-09-12 00:00:00', 'w', 'Polen', 10),
  (18, 'Soraya', '2001-05-12 00:00:00', 'w', 'Deutschland', 10),
  (19, 'Kosimar', '1996-02-13 00:00:00', 'm', 'Deutschland', 11),
  (20, 'Krowian', '2006-12-15 00:00:00', 'm', 'Deutschland', 11),
  (21, 'Andres', '2008-04-09 00:00:00', 'm', 'Deutshland', 11),
  (22, 'Gabriel', '2001-04-01 00:00:00', 'm', 'Schweiz', 11),
  (23, 'Smaragd', '2004-12-23 00:00:00', 'm', 'Schweiz', 11),
  (24, 'Ludwig', '2005-01-01 00:00:00', 'w', 'Österreich', 12),
  (25, 'Richy', '1997-07-01 00:00:00', 'w', 'Luxemburg', 12),
  (26, 'Wallenstein', '2005-05-01 00:00:00', 'm', 'Deutschland', 12),
  (27, 'Haremsdame', '2003-11-04 00:00:00', 'w', 'Holland', 12),
  (28, 'Berta', '1996-03-05 00:00:00', 'w', 'Deutshland', 15),
  (29, 'Bertram', '1997-11-08 00:00:00', 'm', 'Frankreich', 15),
  (30, 'Rosamunde', '2004-12-31 00:00:00', 'w', 'Polen', 9),
  (31, 'Exodus', '2008-09-30 00:00:00', 'w', 'Brasilien', 7),
  (32, 'Isegrim', '2006-12-05 00:00:00', 'm', 'Slowakei', 8),
  (33, 'Ramses', '1983-05-03 00:00:00', 'm', 'Spanien', 1),
  (34, 'Torro', '2003-03-21 00:00:00', 'm', 'Deutschland', 18),
  (35, 'Cleopatra', '2008-10-06 00:00:00', 'w', 'Sambia', 17),
  (36, 'Lolly', '2005-07-14 00:00:00', 'w', 'Tunesien', 16);

-- Re-enable foreign key checks
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;

-- End of script

-- ----------------------------------------------------------------------
-- EOF